@@ -77,6 +77,14 @@ class GitRelease(github.GithubObject.CompletableGithubObject):
         self._completeIfNotSet(self._tag_name)
         return self._tag_name.value
 
+    @property
+    def target_commitish(self):
+        """
+        :type: string
+        """
+        self._completeIfNotSet(self._target_commitish)
+        return self._target_commitish.value
+
     @property
     def draft(self):
         """
@@ -158,13 +166,20 @@ class GitRelease(github.GithubObject.CompletableGithubObject):
         return self._zipball_url.value
 
     def delete_release(self):
+        """
+        :calls: `DELETE /repos/:owner/:repo/releases/:release_id <https://developer.github.com/v3/repos/releases/#delete-a-release>`_
+        :rtype: None
+        """
         headers, data = self._requester.requestJsonAndCheck(
             "DELETE",
             self.url
         )
-        return True
 
     def update_release(self, name, message, draft=False, prerelease=False):
+        """
+        :calls: `PATCH /repos/:owner/:repo/releases/:release_id <https://developer.github.com/v3/repos/releases/#edit-a-release>`_
+        :rtype: :class:`github.GitRelease.GitRelease`
+        """
         assert isinstance(name, str), name
         assert isinstance(message, str), message
         assert isinstance(draft, bool), draft
@@ -184,6 +199,10 @@ class GitRelease(github.GithubObject.CompletableGithubObject):
         return github.GitRelease.GitRelease(self._requester, headers, data, completed=True)
 
     def upload_asset(self, path, label="", content_type=""):
+        """
+        :calls: `POST https://<upload_url>/repos/:owner/:repo/releases/:release_id/assets?name=foo.zip <https://developer.github.com/v3/repos/releases/#upload-a-release-asset>`_
+        :rtype: :class:`github.GitReleaseAsset.GitReleaseAsset`
+        """
         assert isinstance(path, str), path
         assert isinstance(label, str), label
 
@@ -204,6 +223,10 @@ class GitRelease(github.GithubObject.CompletableGithubObject):
         return github.GitReleaseAsset.GitReleaseAsset(self._requester, resp_headers, data, completed=True)
 
     def get_assets(self):
+        """
+        :calls: `GET /repos/:owner/:repo/releases/:release_id/assets <https://developer.github.com/v3/repos/releases/#list-assets-for-a-release>`_
+        :rtype: :class:`github.PaginatedList.PaginatedList`
+        """
         return github.PaginatedList.PaginatedList(
             github.GitReleaseAsset.GitReleaseAsset,
             self._requester,
@@ -216,6 +239,7 @@ class GitRelease(github.GithubObject.CompletableGithubObject):
         self._body = github.GithubObject.NotSet
         self._title = github.GithubObject.NotSet
         self._tag_name = github.GithubObject.NotSet
+        self._target_commitish = github.GithubObject.NotSet
         self._draft = github.GithubObject.NotSet
         self._prerelease = github.GithubObject.NotSet
         self._author = github.GithubObject.NotSet
@@ -236,6 +260,8 @@ class GitRelease(github.GithubObject.CompletableGithubObject):
             self._title = self._makeStringAttribute(attributes["name"])
         if "tag_name" in attributes:
             self._tag_name = self._makeStringAttribute(attributes["tag_name"])
+        if "target_commitish" in attributes:
+            self._target_commitish = self._makeStringAttribute(attributes["target_commitish"])
         if "draft" in attributes:
             self._draft = self._makeBoolAttribute(attributes["draft"])
         if "prerelease" in attributes:
