@@ -441,7 +441,7 @@ class Issue(github.GithubObject.CompletableGithubObject):
     def set_labels(self, *labels):
         """
         :calls: `PUT /repos/:owner/:repo/issues/:number/labels <http://developer.github.com/v3/issues/labels>`_
-        :param label: :class:`github.Label.Label`
+        :param labels: list of :class:`github.Label.Label` or strings
         :rtype: None
         """
         assert all(isinstance(element, (github.Label.Label, str)) for element in labels), labels
@@ -454,7 +454,7 @@ class Issue(github.GithubObject.CompletableGithubObject):
 
     def get_reactions(self):
         """
-        :calls: `GET /repos/:owner/:repo/issues/:number/reactions <https://developer.github.com/v3/reactions/#list-reactions-for-an-issue>`
+        :calls: `GET /repos/:owner/:repo/issues/:number/reactions <https://developer.github.com/v3/reactions/#list-reactions-for-an-issue>`_
         :return: :class: :class:`github.PaginatedList.PaginatedList` of :class:`github.Reaction.Reaction`
         """
         return github.PaginatedList.PaginatedList(
